@@ -131,7 +131,8 @@ if($_REQUEST['submit_value']=='Export'){
 	$return[0][1]="ASR";
 	$return[0][2]="ACD";
 	$return[0][3]="Call Time";
-	$return[0][4]="Call Count";
+	$return[0][4]="Connected Count";
+	//$return[0][5]="All Call Count";
 
 	$i=1;
 	foreach($rsdb as $rs){
@@ -140,6 +141,7 @@ if($_REQUEST['submit_value']=='Export'){
 		$return[$i][2]="".$rs['acd_s'];
 		$return[$i][3]="".$rs['calltime_s'];
 		$return[$i][4]="".$rs['callcount'];
+		//$return[$i][5]=($rs['asr'])?round((float)$rs['callcount']/$rs['asr']):0;
 		$i++;
 	}
 
