@@ -28,7 +28,8 @@ if($action=="del")
 			$send[]=my_pack2('LCSCLL', $checksum, SCH_UPDATE, $row[sim_team_id], 0, 0, 0); //nend update scheduler
 		}
 */
-		$db->query("update device_line set auto_simulation_id='0',next_auto_dial_time='0' where auto_simulation_id='$id'");
+		//$db->query("update device_line set auto_simulation_id='0',next_auto_dial_time='0' where auto_simulation_id='$id'");
+		$db->query("delete from human_ref where auto_simulation_id='$id'");
 		$send[]=pack('La*', $checksum, "auto_update");
 		sendto_xchanged($send);
 		WriteSuccessMsg("<br><li>Delete successful</li>","?");
@@ -140,7 +141,7 @@ else if($action=="grecv"){
                         $start_limit=0;
                         $page=1;
                 }
-                $query=$db->query("SELECT id FROM device_line where auto_simulation_id=$id order by id");
+                $query=$db->query("SELECT device_line.id FROM device_line right join human_ref on device_line.id=human_ref.line_id where human_ref.auto_simulation_id=$id order by device_line.id");
                 $strs0=array();
                 $rcount=0;
                 while($row=$db->fetch_array($query)) {
@@ -150,11 +151,9 @@ else if($action=="grecv"){
                 //echo $rcount;
                 $fenye=showpage2("human.php?action=grecv&id=$id&",$page,$count,$perpage,true,true,"线","myform","boxs");
                 //if(_GET)
-                $query=$db->query("(select device_line.*,name, 1 as 'in' from device_line left join auto_simulation on auto_simulation.id=device_line.auto_simulation_id where device_line.auto_simulation_id=$id order by line_name ASC limit 99999999)
+                $query=$db->query("(select device_line.*, 1 as 'in' from device_line where id in (select line_id from human_ref where human_ref.auto_simulation_id=$id ) order by line_name ASC limit 99999999)
                                 union all
-                                (select *,NULL,0 from device_line where auto_simulation_id=0 order by line_name ASC limit 99999999) 
-                                union all
-                                (select device_line.*,name,2 from device_line left join auto_simulation on auto_simulation.id=device_line.auto_simulation_id where device_line.auto_simulation_id!=0 and device_line.auto_simulation_id!=$id order by line_name ASC limit 99999999)
+                                (select device_line.*,0 from device_line where id not in (select line_id from human_ref where human_ref.auto_simulation_id=$id ) order by line_name ASC limit 99999999) 
                                         LIMIT $start_limit,$perpage");
                 while($row=$db->fetch_array($query)) {
 
@@ -263,7 +262,8 @@ elseif($action=="greceivers"){
         //print_r($strs);
         //$strs=array_unique($strs);
 
-        $query=$db->query("select device_line.*,password from device_line left join rm_device on device_line.goip_name = rm_device.name where auto_simulation_id=$id");
+        //$query=$db->query("select device_line.*,password from device_line left join rm_device on device_line.goip_name = rm_device.name where auto_simulation_id=$id");
+	$query=$db->query("select line_id from human_ref where auto_simulation_id=$id");
 
         while($row=$db->fetch_array($query)) {
                 $flag=0;
@@ -286,7 +286,8 @@ elseif($action=="greceivers"){
                 $delstrs=substr($delstrs,0,strlen($delstrs)-1);
                 //WriteSuccessMsg("delete from receiver where id in ($delstrs)","groups.php?action=recv&id=$id");
                 //echo "update goip set goip_team_id=0 where goipid in ($delstrs)";
-                $db->query("update device_line set auto_simulation_id=0,next_auto_dial_time='0' where id in ($delstrs)");
+                //$db->query("update device_line set auto_simulation_id=0,next_auto_dial_time='0' where id in ($delstrs)");
+		$db->query("delete from human_ref where auto_simulation_id=$id and line_id in ($delstrs)");
         }
         if(count($strs)){
                 //echo "111111";
@@ -294,12 +295,12 @@ elseif($action=="greceivers"){
                 foreach($strs as $rkey => $rgid){
                         //$sql.="(NULL,$id,$rgid),";
                         $insertstr.=$rgid.",";
-
+			$db->query("insert into human_ref set auto_simulation_id=$id,line_id=$rgid");
                 }
                 $insertstr=substr($insertstr,0,strlen($insertstr)-1);
                 //WriteSuccessMsg($sql,"groups.php?action=recv&id=$id");
                 //echo "update goip set goip_team_id=$id where goipid in ($insertstr)";
-                $db->query("update device_line set auto_simulation_id=$id where id in ($insertstr)");
+                //$db->query("update device_line set auto_simulation_id=$id where id in ($insertstr)");
         }
         if($send)
                 sendto_xchanged($send);
@@ -336,7 +337,7 @@ elseif($action=="greceivers"){
 		if($row['disable']) $row['enable']='N';
 		else $row['enable']='Y';
 		$channel_on_c=0; $channel_all_c=0;
-		$query1=$db->query("select line_status, count(*) as c from device_line where auto_simulation_id=$row[id] group by line_status"); 
+		$query1=$db->query("select line_status, count(*) as c from device_line where id in (select line_id from human_ref where auto_simulation_id=$row[id]) group by line_status"); 
 		while($row1=$db->fetch_array($query1)){
                         if($row1['line_status']!=0 &&$row1['line_status']!=12) $channel_on_c+=$row1['c'];
                         $channel_all_c+=$row1['c'];
