@@ -326,6 +326,22 @@
 	@$db->updatequery("ALTER TABLE  `auto_simulation` CHANGE  `dial_num`  `dial_num` VARCHAR( 4000 ) CHARACTER SET latin1 COLLATE latin1_swedish_ci NOT NULL");
 	@$db->updatequery("ALTER TABLE  `auto_simulation` ADD `period_type` int(11) NOT NULL default '0'");
 	@$db->updatequery("ALTER TABLE  `auto_simulation` ADD `period_setting` varchar(2000) NOT NULL");
+
+/*1.6.3 2015-6-15 17:21:37*/
+	if(!$rs || $rs[0] < 109){
+		@$db->updatequery("update `system` set `version`='109'");
+        	@$db->updatequery("CREATE TABLE IF NOT EXISTS `human_ref` (
+  `id` int(11) NOT NULL auto_increment,
+  `line_id` int(11) NOT NULL,
+  `auto_simulation_id` int(11) NOT NULL,
+  PRIMARY KEY  (`id`),
+  KEY `sim_name` (`line_id`,`auto_simulation_id`)
+) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;");
+		$query=@$db->updatequery("select id,auto_simulation_id from device_line where auto_simulation_id!=0");
+		while($row=$db->fetch_array($query)){
+			$db->updatequery("insert into human_ref set line_id='$row[id]', auto_simulation_id='$row[auto_simulation_id]'");
+		}
+	}
 	
 	echo "update done! <a href=''  target=_top>Return</a>";
 
